@@ -5,17 +5,33 @@
 # License: GNU General Public License v3.0
 
 from __future__ import print_function
-import warnings
+import json, warnings, os, pathlib
 import numpy as np
 import gc
-from .independence_tests_base import CondIndTest
+try:
+    from importlib import metadata
+except ImportError:
+    import importlib_metadata as metadata  # python<=3.7
 try:
     import dcor
     import torch
     import gpytorch
     from .LBFGS import FullBatchLBFGS
+    with open(pathlib.Path(os.path.dirname(__file__)) / '../../versions.py', 'r') as vfile:
+        packages = json.loads(vfile.read())['all']
+        packages = dict(map(lambda s: s.split('>='), packages))
+        if metadata.version('dcor') < packages['dcor']:
+            raise Exception('Version mismatch. Installed version of dcor', metadata.version('dcor'),
+                            'Please install dcor>=', packages['dcor'])
+        if metadata.version('torch') < packages['torch']:
+            raise Exception('Version mismatch. Installed version of torch', metadata.version('torch'),
+                            'Please install torch>=', packages['torch'])
+        if metadata.version('gpytorch') < packages['gpytorch']:
+            raise Exception('Version mismatch. Installed version of gpytorch', metadata.version('gpytorch'),
+                          'Please install gpytorch>=', packages['gpytorch'])
 except Exception as e:
     warnings.warn(str(e))
+from .independence_tests_base import CondIndTest
 
 class GaussProcRegTorch():
     r"""Gaussian processes abstract base class.
@@ -217,10 +233,16 @@ class GaussProcRegTorch():
         # Standardize
         if standardize:
             array -= array.mean(axis=1).reshape(dim, 1)
-            array /= array.std(axis=1).reshape(dim, 1)
-            if np.isnan(array).any():
-                raise ValueError("Nans after standardizing, "
-                                 "possibly constant array!")
+            std = array.std(axis=1)
+            for i in range(dim):
+                if std[i] != 0.:
+                    array[i] /= std[i]
+            if np.any(std == 0.):
+                warnings.warn("Possibly constant array!")
+            # array /= array.std(axis=1).reshape(dim, 1)
+            # if np.isnan(array).any():
+            #     raise ValueError("Nans after standardizing, "
+            #                      "possibly constant array!")
 
         target_series = array[target_var, :]
         z = np.fastCopyAndTranspose(array[2:])
